# serialization

## Purpose
Body encoding and content-type constants.

## Owns
- JSON conversion from Python values.
- Canonical content type values.

## Entry Points
- `serialization::json::to_json_bytes`

## Not Here
- HTTP socket loop.
